==> cds-services-impl-1.12.0-sources.jar: com/sap/cds/services/impl/messaging/file/FileBasedMessagingService.java <==
/**************************************************************************
 * (C) 2019-2020 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.messaging.file;

import java.io.File;
import java.io.IOException;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.sap.cds.feature.config.pojo.CdsProperties.Messaging.MessagingServiceConfig;
import com.sap.cds.services.utils.messaging.service.AbstractMessagingService;
import com.sap.cds.services.utils.messaging.service.MessagingBrokerQueueListener;

/**
 * Implementation of the {@code MessagingBrokerConnector} for the file based
 * messaging service.
 */
public class FileBasedMessagingService extends AbstractMessagingService {

	public static final String FILE_KIND = "file-based-messaging";
	private static final Logger logger = LoggerFactory.getLogger(FileBasedMessagingService.class);

	private final FileBasedMessagingBroker broker;

	public FileBasedMessagingService(MessagingServiceConfig serviceConfig) throws IOException {
		super(serviceConfig);

		File file;
		if (serviceConfig.getBinding() == null) {
			file = File.createTempFile("messagexchange", ".txt");
		} else {
			file = new File(serviceConfig.getBinding());
			if (!file.exists() && !file.createNewFile()) {
				throw new IOException("The specified file '" + file.getAbsolutePath() + "' for the file based messaging service could not be created.");
			}
		}

		logger.info("Using '{}' for file-based message exchange", file.getAbsolutePath());
		this.broker = FileBasedMessagingBroker.connect(getName(), file);
	}

	@Override
	protected void removeQueue(String name) {
		// nothing to do
	}

	@Override
	protected void createQueue(String name, Map<String, String> properties) {
		// nothing to do
	}

	@Override
	protected void createQueueSubscription(String queue, String topic) {
		broker.subscribeTopic(queue, topic);
	}

	@Override
	protected void registerQueueListener(String queue, MessagingBrokerQueueListener listener) {
		broker.listenToQueue(queue, (msg, topic, messageId) -> {
			listener.receivedMessage(msg, topic, messageId);
		});
	}

	@Override
	protected void emitTopicMessage(String topic, String message) {
		broker.emitMessage(topic, message);
	}

}

==> cds-services-impl-1.14.1-sources.jar: com/sap/cds/services/impl/messaging/file/FileBasedMessagingService.java <==
/**************************************************************************
 * (C) 2019-2021 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.messaging.file;

import java.io.File;
import java.io.IOException;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.sap.cds.feature.config.pojo.CdsProperties.Messaging.MessagingServiceConfig;
import com.sap.cds.reflect.CdsModel;
import com.sap.cds.services.utils.messaging.service.AbstractMessagingService;
import com.sap.cds.services.utils.messaging.service.MessagingBrokerQueueListener;

/**
 * Implementation of the {@code MessagingBrokerConnector} for the file based
 * messaging service.
 */
public class FileBasedMessagingService extends AbstractMessagingService {

	public static final String FILE_KIND = "file-based-messaging";
	private static final Logger logger = LoggerFactory.getLogger(FileBasedMessagingService.class);

	private final FileBasedMessagingBroker broker;

	public FileBasedMessagingService(MessagingServiceConfig serviceConfig, CdsModel model) throws IOException {
		super(serviceConfig, model);

		File file;
		if (serviceConfig.getBinding() == null) {
			file = File.createTempFile("messagexchange", ".txt");
		} else {
			file = new File(serviceConfig.getBinding());
			if (!file.exists() && !file.createNewFile()) {
				throw new IOException("The specified file '" + file.getAbsolutePath() + "' for the file based messaging service could not be created.");
			}
		}

		logger.info("Using '{}' for file-based message exchange", file.getAbsolutePath());
		this.broker = FileBasedMessagingBroker.connect(getName(), file);
	}

	@Override
	protected void removeQueue(String name) {
		// nothing to do
	}

	@Override
	protected void createQueue(String name, Map<String, String> properties) {
		// nothing to do
	}

	@Override
	protected void createQueueSubscription(String queue, String topic) {
		broker.subscribeTopic(queue, topic);
	}

	@Override
	protected void registerQueueListener(String queue, MessagingBrokerQueueListener listener) {
		broker.listenToQueue(queue, (msg, topic, messageId) -> {
			listener.receivedMessage(msg, topic, messageId);
		});
	}

	@Override
	protected void emitTopicMessage(String topic, String message) {
		broker.emitMessage(topic, message);
	}

}
